@@ -775,9 +775,7 @@ class EasyClient(object):
 
         return self.client.post_export_jobs(payload)  # noqa # wrapper changes type
 
-    @wrap_response(
-        parse_method="parse_job_ids", parse_many=True, default_exc=FetchError
-    )
+    @wrap_response(parse_method="parse_job_ids")
     def import_jobs(self, job_list):
         # type: (List[Job]) -> List[str]
         """Import job definitions from a list of Jobs.
@@ -845,6 +843,17 @@ class EasyClient(object):
         """
         return self._patch_job(job_id, [PatchOperation("update", "/status", "RUNNING")])
 
+    def execute_job(self, job_id):
+        """Execute a Job
+
+        Args:
+            job_id (str): The Job ID
+
+        Returns:
+            Request: The returned request
+        """
+        return self.client.post_execute_job(job_id)
+
     @wrap_response(parse_method="parse_resolvable")
     def upload_bytes(self, data):
         # type: (bytes) -> Any
