@@ -77,9 +77,14 @@ def _domain_identifier_schema_selector(_, role_assignment_domain):
     scope_schema_map = {
         "Garden": GardenDomainIdentifierSchema,
         "System": SystemDomainIdentifierSchema,
+        "Global": Schema,
     }
 
-    scope = role_assignment_domain.get("scope")
+    if isinstance(role_assignment_domain, dict):
+        scope = role_assignment_domain.get("scope")
+    else:
+        scope = role_assignment_domain.scope
+
     schema = scope_schema_map.get(scope)
 
     if schema is None:
@@ -333,6 +338,9 @@ class RequestSchema(RequestTemplateSchema):
     error_class = fields.Str(allow_none=True)
     created_at = DateTime(allow_none=True, format="epoch", example="1500065932000")
     updated_at = DateTime(allow_none=True, format="epoch", example="1500065932000")
+    status_updated_at = DateTime(
+        allow_none=True, format="epoch", example="1500065932000"
+    )
     has_parent = fields.Bool(allow_none=True)
     requester = fields.String(allow_none=True)
 
@@ -562,7 +570,7 @@ class ResolvableSchema(BaseSchema):
 class RoleSchema(BaseSchema):
     id = fields.Str()
     name = fields.Str()
-    description = fields.Str()
+    description = fields.Str(allow_none=True)
     permissions = fields.List(fields.Str())
 
 
@@ -571,7 +579,7 @@ class RoleAssignmentDomainSchema(BaseSchema):
     identifiers = PolyField(
         serialization_schema_selector=_domain_identifier_schema_selector,
         deserialization_schema_selector=_domain_identifier_schema_selector,
-        required=True,
+        required=False,
     )
 
 
